packageName = "$package-name$"
#UPDATE LOCATE PACKAGE TO LATEST VER ON PYPI
from grtoolkit.Windows import cmd
install_package = f'pip install --upgrade {packageName} --user'
cmd(install_package,
    install_package)